==> haskell-bv-sized-1.0.5-124-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bv-sized.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bv-sized
version:              1.0.5
visibility:           public
id:                   bv-sized-1.0.5-A7F58ob4yQ4L34oHZ6oK3K
key:                  bv-sized-1.0.5-A7F58ob4yQ4L34oHZ6oK3K
license:              BSD-3-Clause
copyright:            Galois Inc., Ben Selfridge March 2018
maintainer:           benselfridge@galois.com
author:               Ben Selfridge
homepage:             https://github.com/GaloisInc/bv-sized
synopsis:
    a bitvector datatype that is parameterized by the vector width

description:
    This module defines a width-parameterized bitvector type and various associated operations.

category:             Bit Vectors
abi:                  bcf6798dc487fc9f297f0325fe7a97a9
exposed:              True
exposed-modules:
    Data.BitVector.Sized Data.BitVector.Sized.Overflow
    Data.BitVector.Sized.Signed Data.BitVector.Sized.Unsigned

hidden-modules:
    Data.BitVector.Sized.Internal Data.BitVector.Sized.Panic

import-dirs:          /usr/lib/ghc-9.4.8/site-local/bv-sized-1.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bv-sized-1.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bv-sized-1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bv-sized
hs-libraries:         HSbv-sized-1.0.5-A7F58ob4yQ4L34oHZ6oK3K
depends:
    base-4.17.2.1 bitwise-1.0.0.1-2KsseIIL0t49WRK2D0Fn2z
    bytestring-0.11.5.3 deepseq-1.4.8.0
    panic-0.4.0.1-43gjwtFDWNE3rZ0eFzNWpd
    parameterized-utils-2.1.10.0-KWvQAO7rr6o7z9gRmfX1Yy
    random-1.2.1.2-2GxRLB29YjZ5Hmc9ZOWGpv
    th-lift-0.8.4-3Jqcte1pbUvKHGfrg0advG

haddock-interfaces:   /usr/share/doc/haskell-bv-sized/html/bv-sized.haddock
haddock-html:         /usr/share/doc/haskell-bv-sized/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bv-sized-1.0.5-126-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bv-sized.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bv-sized
version:              1.0.5
visibility:           public
id:                   bv-sized-1.0.5-KsSga6UUqSp60uYhCPSV8u
key:                  bv-sized-1.0.5-KsSga6UUqSp60uYhCPSV8u
license:              BSD-3-Clause
copyright:            Galois Inc., Ben Selfridge March 2018
maintainer:           benselfridge@galois.com
author:               Ben Selfridge
homepage:             https://github.com/GaloisInc/bv-sized
synopsis:
    a bitvector datatype that is parameterized by the vector width

description:
    This module defines a width-parameterized bitvector type and various associated operations.

category:             Bit Vectors
abi:                  6bc2cba1effdcfae0e2bcdbcb118d7ea
exposed:              True
exposed-modules:
    Data.BitVector.Sized Data.BitVector.Sized.Overflow
    Data.BitVector.Sized.Signed Data.BitVector.Sized.Unsigned

hidden-modules:
    Data.BitVector.Sized.Internal Data.BitVector.Sized.Panic

import-dirs:          /usr/lib/ghc-9.4.8/site-local/bv-sized-1.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bv-sized-1.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bv-sized-1.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bv-sized
hs-libraries:         HSbv-sized-1.0.5-KsSga6UUqSp60uYhCPSV8u
depends:
    base-4.17.2.1 bitwise-1.0.0.1-2KsseIIL0t49WRK2D0Fn2z
    bytestring-0.11.5.3 deepseq-1.4.8.0
    panic-0.4.0.1-43gjwtFDWNE3rZ0eFzNWpd
    parameterized-utils-2.1.10.0-KWvQAO7rr6o7z9gRmfX1Yy
    random-1.2.1.2-2GxRLB29YjZ5Hmc9ZOWGpv
    th-lift-0.8.4-3Jqcte1pbUvKHGfrg0advG

haddock-interfaces:   /usr/share/doc/haskell-bv-sized/html/bv-sized.haddock
haddock-html:         /usr/share/doc/haskell-bv-sized/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
